@@ -54,6 +54,8 @@ class ChatConfig:
             "retry_delay": 2.0,
             "timeout": 120.0,
             "spinner_style": "dots",
+            # Suppress agent library stdout during streaming
+            "suppress_agent_stdout": True,
         },
         "ui": {
             "show_banner": True,
@@ -343,13 +345,13 @@ def initialize_default_config() -> Path:
 # COLORS - ANSI escape codes for terminal output
 # ============================================================================
 colors:
-  user: '\\033[97m'      # Bright white - maximum contrast
-  agent: '\\033[94m'     # Bright blue
-  system: '\\033[33m'    # Yellow
-  error: '\\033[91m'     # Bright red
-  success: '\\033[92m'   # Bright green
-  dim: '\\033[2m'        # Dim
-  reset: '\\033[0m'      # Reset
+  user: '\\\\033[97m'      # Bright white - maximum contrast
+  agent: '\\\\033[94m'     # Bright blue
+  system: '\\\\033[33m'    # Yellow
+  error: '\\\\033[91m'     # Bright red
+  success: '\\\\033[92m'   # Bright green
+  dim: '\\\\033[2m'        # Dim
+  reset: '\\\\033[0m'      # Reset
 
 # ============================================================================
 # FEATURES - Toggle optional functionality
@@ -375,6 +377,9 @@ behavior:
   retry_delay: 2.0             # Seconds to wait between retries
   timeout: 120.0               # Request timeout in seconds
   spinner_style: dots          # Thinking indicator style (dots, line, arc, etc.)
+  suppress_agent_stdout: true  # Suppress agent library stdout during streaming
+                               # (prevents double-output from some agent libraries)
+                               # Note: Does NOT suppress tool calls or logging
 
 # ============================================================================
 # UI - User interface preferences
